"use strict";

const { images_url } = require("../../../constants");
const WebPage = require("../../lib/web-page");
// const GameStudioClub = require("./components/game-studio-club");
// const Popularization = require("./components/popularization");

const EDU_THEMES = [
    {
        title: "Game Studio Club",
        description: "Conception, graphisme et animation, programmation, je vous accompagne dans la découverte des techniques pour créer un jeu vidéo de A à Z",
        image: "learning_theme_conception.png",
        pageUrl: "game-studio-club",
    },
    {
        title: "Programmation",
        description: "Vous avez une idée de projet à réaliser en programmation ou vous êtes simplement curieux ? Apprenez à programmer avec différent langages, pour du web du logiciel ou du jeu vidéo.",
        image: "learning_theme_coding.png",
        pageUrl: "coding",
    },
    {
        title: "Dessin numérique et animation 2D",
        description: "Maîtriser des logiciels libres de création graphique 2D et d'animation.",
        image: "learning_theme_2d.png",
        pageUrl: "2d",
    },
    {
        title: "Maths et physiques",
        description: "Fâché avec les maths ? Aborder les notions fondamentales de façon décontractée pour le plaisir de comprendre.",
        image: "learning_theme_math.png",
        pageUrl: "math",
    },
    {
        title: "Musique et sons électroniques",
        description: "Maîtriser des logiciels libres de composition musicales, de synthèse sonore et de prise de son.",
        image: "learning_theme_sound.png",
        pageUrl: "sound",
    },
    {
        title: "Aide informatique générale",
        description: "Perdu avec votre ordinateur ou votre smartphone, les logicels, internet ? Je vous aide pas à pas à comprendre les fondamentaux et à utiliser sereinement la technologie.",
        image: "learning_theme_pc.png",
        pageUrl: "popularization"
    }
];

class EducationPage extends WebPage {

    render() {
        return {
            tag: "div",
            id: "education-page",
            typeof: "EducationalOrganization",
            contents: [
                {
                    tag: "div",
                    class: "page-header logo-left",
                    contents: [
                        {
                            tag: "div",
                            class: "page-contents-center grid-wrapper",
                            contents: [
                                {
                                    tag: "div",
                                    class: "logo",
                                    contents: [
                                        {
                                            tag: "img",
                                            alt: "image brain",
                                            src: `${images_url}brain.svg`,
                                        },
                                    ],
                                },
                                { tag: "h1", contents: "Pédagogie" },
                                {
                                    tag: "p",
                                    contents: `Animations autour de la création de jeux vidéos, vulgarisation numérique.`,
                                },
                            ],
                        },
                    ],
                },
                {
                    tag: "div",
                    class: "title-banner",
                },
                {
                    tag: "div",
                    class: "page-contents-center",
                    contents: [
                        {
                            tag: "p",
                            class: "edu-pitch",
                            contents: `La pédagogie est un des objectifs majeurs de Kuadrado Software. <br />
                            L'informatique est aujourd'hui un élément incontournable de notre société et j'ai la conviction 
                            qu'il est fondamental de pouvoir accéder de façon simple à une forme d'apprentissage et de partage de connaissances.<br />
                            Je propose donc des séances d'enseignement autour des sujets que je suis en position de transmettre en tant que développeur et artiste.`
                        },
                        {
                            tag: "ul",
                            class: "edu-themes",
                            contents: EDU_THEMES.map(theme => {
                                return {
                                    tag: "li",
                                    class: "edu-theme",
                                    contents: [
                                        {
                                            tag: "a",
                                            href: theme.pageUrl,
                                            contents: [
                                                { tag: "h3", contents: theme.title },
                                                { tag: "img", class: "pixelated", src: `${images_url}/${theme.image}` },
                                                { tag: "p", contents: theme.description },
                                            ]
                                        }

                                    ]
                                }
                            })
                        },
                        {
                            tag: "div",
                            contents: "Pour qui ? Tout le monde à partir de 12 ans, ados ou adultes."
                        },
                        {
                            tag: "div",
                            contents: "Ou ça ? Dans mon local professionel 32 rue Simon Vialet Vernoux"
                        },
                        {
                            tag: "div",
                            contents: "Tarfs: 60 bal par mois. Ou 30€/h pour des cours particuliers, visio possible."
                        },
                        {
                            tag: "div",
                            contents: "Horaires: mardi 17h 18h30, mercredi 15h 16h30, jeudi 17h 18h30"
                        },
                        {
                            tag: "div",
                            contents: "Matos informatique fournis sur place, on peut amener le sien si on veut."
                        },
                        {
                            tag: "div",
                            contents: "Pour s'inscrire: Me contacter ou passer me voir. Télécharger le ficher d'inscription -> ici"
                        }
                    ]
                },

            ],
        };
    }
}

module.exports = EducationPage;
